#
# spec file for package python-Levenshtein
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Levenshtein
Version:        0.26.1
Release:        1.3
Summary:        Python extension computing string distances and similarities
License:        GPL-2.0-or-later
URL:            https://github.com/rapidfuzz/Levenshtein
Source:         https://files.pythonhosted.org/packages/source/l/levenshtein/levenshtein-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scikit-build-core >= 0.10.6}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  python-rpm-macros
Requires:       (python-rapidfuzz >= 3.9.0 with python-rapidfuzz < 4.0.0)
%python_subpackages

%description
The Levenshtein Python C extension module contains functions for fast
computation of

 * Levenshtein (edit) distance, and edit operations
 * string similarity
 * approximate median strings, and generally string averaging
 * string sequence and set similarity

It supports both normal and Unicode strings.

%prep
%setup -q -n levenshtein-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license COPYING
%doc HISTORY.md README.md
%{python_sitearch}/

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.26.1:
  * add missing mac os wheels
* Mon Sep 23 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.26.0
  * Add support for Python 3.13
  * Drop support for Python 3.8
  * Switch build system to `scikit-build-core`
  * Upgrade to `Cython==3.0.11`
- Adjust upstream source name in spec file
- Update BuildRequires from pyproject.toml
* Tue May 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.25.1
  * Fix potentially incorrect results of `jaro_winkler`
    when using high prefix weights
- from version 0.25.0
  * Improve type hints
- from version 0.24.0
  * Upgrade ``rapidfuzz-cpp`` to ``v3.0.0``
  - Drop support for Python 3.7
- from version 0.23.0
  * Added keyword argument `pad` to Hamming distance. This controls
    whether sequences of different length should be padded or lead
    to a `ValueError`
  * Upgrade to `Cython==3.0.3`
- from version 0.22.0
  * Add support for Python 3.12
  * Drop support for Python 3.6
  * Add wheels for windows arm64
- from version 0.21.1
  * Upgrade ``rapidfuzz-cpp`` to ``v2.0.0``
- from version 0.21.0
  * Relax dependency requirement on ``rapidfuzz``
- from version 0.20.9
  * Fix function signature of `get_requires_for_build_wheel`
- from version 0.20.8
  - Type hints for `editops`/`opcoded`/`matching_blocks` did not allow any
    hashable sequence
- from version 0.20.7
  - Type hints did not get installed
- from version 0.20.6
  - Fix incorrect result normalization in `setratio` and `seqratio`
- from version 0.20.5
  * Fix support for cmake versions below 3.17
  * Fix version requirement for `rapidfuzz-cpp` when building
    against a previously installed version
- from version 0.20.4
  * Modernize cmake build to fix most conda-forge builds
- from version 0.20.3
  * Added support for Python 3.11
- from version 0.20.2
  * Fix matching_blocks conversion for empty editops
  * Added in-tree build backend to install cmake and ninja only when
    it is not installed yet and only when wheels are available
- from version 0.20.1
  * Fix broken matching_blocks conversion
- from version 0.20.0
  * Use `matching_blocks`/`apply`/`remove_subsequence`/`inverse`
    implementation from RapidFuzz
  * Stop adding data to wheels
  * Fix segmentation fault on some invalid editop sequences in subtract_edit
  * Detect duplicated entries in editops validation
- from version 0.19.3
  * Add musllinux wheels
- from version 0.19.2
  * Add missing type hints
- from version 0.19.1
  * Add type hints
- from version 0.19.0
  * Implement all Python wrappers mostly with cython
  * Replace usage of deprecated Python APIs
  * Fix behavior of median and median_improve
- from version 0.18.2
  * Allow installation from system installed versions of `rapidfuzz-cpp`
- from version 0.18.1
  * Indel.normalized_similarity was broken in RapidFuzz v2.0.0 (see #20)
- from version 0.18.0
  * Fixed memory leak in error path of setratio
  * Fixed out of bound reads due to uninitialized variable in median
  * e.g. quickmedian(["test", "teste"], [0, 0]) caused out of bound reads
  * Use a faster editops implementation provided by RapidFuzz
  * Reduce code duplication
  * Reuse implementations from rapidfuzz-cpp
  * Transition to scikit-build
- from version 0.17.0
  * Removed support for Python 3.5
- from version 0.16.1
  * Add support for RapidFuzz v1.9.*
- from version 0.16.0
  * Add support for Python 3.10
- from version 0.15.0
  * Update SequenceMatcher interface to support the autojunk parameter
- from version 0.14.0
  * Drop Python 2 support
  * Fixed free of non heap object due caused by zero offset on a heap object
  * Fixed warnings about missing type conversions
  * Fix segmentation fault in subtract_edit when incorrect input types are used
  * Fixed unchecked memory allocations
  * Implement distance/ratio/hamming/jaro/jaro_winkler
    using rapidfuzz instead of providing a own implementation
  * Implement Wrapper for inverse/editops/opcodes/matching_blocks/subtract_edit/apply_edit
    using Cython to simplify support for new Python versions
- from version 0.13.0
  * Maintainership passed to Max Bachmann
  * Use faster bitparallel implementations for distance and ratio
  * Avoid string copies in distance, ratio and hamming
  * Fix usage of deprecated Unicode APIs in distance, ratio and hamming
  * Fixed incorrect window size inside Jaro and Jaro-Winkler implementation
  * Fixed incorrect exception messages
  * Removed unused functions and compiler specific hacks
  * Split the Python and C implementations to simplify building of
    the C library
  * Fixed multiple bugs which prevented the use as C library, since some functions
    only got defined when compiling for Python
  * Build and deliver python wheels for the library
  * Fixed incorrect allocation size in lev_editops_matching_blocks and
    lev_opcodes_matching_blocks
- from version 0.12.1
  * Fixed handling of numerous possible wraparounds in calculating the size
    of memory allocations; incorrect handling of which could cause denial
    of service or even possible remote code execution in previous versions
    of the library.
- Remove NEWS file from %%files section
- Rename HISTORY.txt to HISTORY.md in %%files section
- Rename README.rst to README.md in %%files section
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
- Switch to new upstream project Levenshtein
  * Adjust upstream source name in spec file
  * Update URL to GitHub project
  * Update Source URL for upstream tarball
- Update BuildRequires from pyproject.toml
* Sun Feb  4 2024 Axel Braun <axel.braun@gmx.de>
- enable %%{?sle15_python_module_pythons}
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Thu Aug  2 2018 tchvatal@suse.com
- Install license file
- Remove duplicates
* Fri Jun 30 2017 jmatejek@suse.com
- convert to singlespec
- drop *.c and *.h from installed package
* Sun Dec 21 2014 termim@gmail.com
- updated to version 0.12
  * Fixed a bug in StringMatcher.StringMatcher.get_matching_blocks /
    extract_editops for Python 3; now allow only `str` editops on both
    Python 2 and Python 3, for simpler and working code.
  * Added documentation in the source distribution and in GIT
  * Fixed the package layout: renamed the .so/.dll to _levenshtein, and
    made it reside inside a package, along with the StringMatcher class.
  * Fixed spelling errors.
- updated to version 0.11.2
  * Fixed a bug in setup.py: installation would fail on Python 3 if the
    locale  did not specify UTF-8 charset (Felix Yan).
  * Added COPYING, StringMatcher.py, gendoc.sh and NEWS in MANIFEST.in, as
    they  were missing from source distributions.
* Thu Jan 30 2014 elchevive@opensuse.org
- updated to version 0.11.1
  * Added Python 3 support
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jan 31 2012 saschpe@suse.de
- Simplified macro usage
- Don't package PKG-INFO or MANIFEST, this is setuptools bloat
- Removed outdated %%clean section
* Tue Jan 31 2012 elchevive@opensuse.org
- change from python-setuptools to python-distribute
* Thu Jan 26 2012 elchevive@opensuse.org
- spec cleaning, remove --record-from-files
* Fri Nov 26 2010 cfarrell@novell.com
- initial build. this package is needed to build and use the python wurfl package
